@@ -9,6 +9,7 @@ available to Controllers. This module is available to templates as 'h'.
 
 import logging
 import datetime
+import calendar
 import pytz #@UnresolvedImport
 import time
 from math import log as lg
@@ -152,12 +153,12 @@ def str_to_timestamp(t_str):
     """
     Convert time string in local timezone to UTC seconds
     """
-    #tz = g.get_config('timezone') 
+    tz = get_config('timezone') 
     dt = datetime.datetime.strptime(t_str, '%Y-%m-%d %H:%M')
-    #dt_loc = tz.localize(dt)
-    #dt_utc = dt_loc.astimezone(pytz.utc)
+    dt_loc = tz.localize(dt)
+    dt_utc = dt_loc.astimezone(pytz.utc)
     
-    return time.mktime(dt.timetuple())
+    return calendar.timegm(dt_utc.timetuple())
 
 def span_info(text, escape=True):
     if escape:
@@ -245,11 +246,16 @@ def get_public_tags_cloud(force_reload=False):
         if len(counts) != 0:
             min_count = min(counts)
             max_counts = max(counts)
-            lmm = lg(max_counts) - lg(min_count)
-            
-            weights = [ ( x[0], (lg(x[1])-lg(min_count))/lmm ) for x in items ]
-            
-            weights = [ (x[0], 5*(int(100*x[1])/5)) for x in weights ]
+
+            if min_count == max_counts:
+                # i.e. all tags counts are the same, so they have the same weight
+                weights = [ (x[0], 50) for x in items ]
+            else:
+                lmm = lg(max_counts) - lg(min_count)
+                
+                weights = [ ( x[0], (lg(x[1])-lg(min_count))/lmm ) for x in items ]
+                
+                weights = [ (x[0], 5*(int(100*x[1])/5)) for x in weights ]
             
             _cache['tags_cloud'] = weights
         else:
@@ -284,4 +290,4 @@ def get_pages_widget_links(lang_code, force_reload=False):
 def get_not_approved_comments_count():
     dbsession = DBSession()
     cnt = dbsession.query(func.count(Comment.id)).filter(Comment.is_approved==False).scalar()
-    return cnt
\ No newline at end of file
+    return cnt
