@@ -66,8 +66,8 @@ def save_settings_ajax(request):
               'comment_answer_msg_subject_tpl', 'comment_answer_msg_body_tpl',
               'admin_notify_new_comment_subject_tpl', 'admin_notify_new_comment_body_tpl',
               'admin_notify_new_user_subject_tpl', 'admin_notify_new_user_body_tpl',
-              'verification_msg_body_tpl', 'image_preview_width', 'google_analytics_id',
-              'tw_consumer_key', 'tw_consumer_secret')
+              'verification_msg_body_tpl', 'image_preview_width', 'google_analytics_id', 
+              'timezone', 'tw_consumer_key', 'tw_consumer_secret')
         for id in settings:
             try:
                 v = request.POST[id]
@@ -784,4 +784,4 @@ def save_pages_widget_settings_ajax(request):
     log.debug(widget_pages_pages_spec)
     config.set('widget_pages_pages_spec', widget_pages_pages_spec)
     config.clear_cache()
-    return c
\ No newline at end of file
+    return c
